@@ -28,7 +28,7 @@ def get_list(
             nome_linha,
             nome_grupo,
             qtd * (pag - 1),
-            pag,
+            qtd,
         ),
     )
 
